==> core-2.0.1.0-sources.jar: io/adbrix/sdk/data/SdkVersion.java <==
package io.adbrix.sdk.data;

public class SdkVersion {

    private SdkVersion(){}

    public final static String API_VERSION = "5.0.0";
    public final static String SDK_VERSION = "2.0.1.0";

    /**
     * SDK Update Log
     */
    /**
     * 
     * Date 20210610 : Release 2.0.1.0
     * - Deeplink intent action error 수정
     * - Delete User and Stop SDK API
     * - Restart SDK API
     * - Parse push data API
     * - Open push tracking API
     * - Notification Channel API
     * - LogListener
     *
     * Date 20210503 : Release 2.0.0.8
     * - separate module
     *
     * Date 20210503 : Release 2.0.0.7
     * - androidx dependency 제거
     *
     * Date 20210503 : Release 2.0.0.6
     * - Sonatype에 업로드.
     * - Sonatype library version 과 sdk version 일치시킴
     *
     * Date 20210503 :
     * - Skip 2.0.0.5 version.
     *
     * Date 20210426 : Release 2.0.0.4
     * - EventBundleModelProvider nullPointerException수정
     *
     * Date 20210420 : Release 2.0.0.3
     * - exclude logging with manifest metadata
     * - time in front of log_id is set when controller handle the event
     * - deeplink_open after remain in background state for 60 seconds bug fix(on api 29)
     * - is_push_enable default value true
     *
     * Date 20210331 : Release 2.0.0.2
     * - logging with debug app
     * - loginEvent without param, user_id only in userProperties
     * - deeplinkListener
     *
     * Date 20210323 : Release 2.0.0.1
     * - timer.cancel NullPointerException Handling
     *
     * Date 20210311 : Release 2.0.0.0
     * - Adbrix Remaster SDK v2 Release
     *
     */
 }

==> core-2.0.1.1-sources.jar: io/adbrix/sdk/data/SdkVersion.java <==
package io.adbrix.sdk.data;

public class SdkVersion {

    private SdkVersion(){}

    public final static String API_VERSION = "5.0.0";
    public final static String SDK_VERSION = "2.0.1.1";

    /**
     * SDK Update Log
     */
    /**
     *
     * Date 20210611 : Release 2.0.1.1
     * - Deeplink Event With Intent API
     * - AdBrixCustomLogicFlag 추가
     * - Deferred deeplink 때 중복 성과 집계 방지
     *
     * Date 20210610 : Release 2.0.1.0
     * - Parse Push Data API
     * - Open Push API
     * - Deeplink intent action error 수정
     * - Delete User and Stop SDK API
     * - Restart SDK API
     * - Parse push data API
     * - Open push tracking API
     * - Notification Channel API
     * - LogListener
     * - config variable 에 default 값 설정
     * - default event upload mode
     * - 중복 user_property update 방지
     * - EventModel Parsing error 수정
     *
     * Date 20210503 : Release 2.0.0.8
     * - separate module
     *
     * Date 20210503 : Release 2.0.0.7
     * - androidx dependency 제거
     *
     * Date 20210503 : Release 2.0.0.6
     * - Sonatype에 업로드.
     * - Sonatype library version 과 sdk version 일치시킴
     *
     * Date 20210503 :
     * - Skip 2.0.0.5 version.
     *
     * Date 20210426 : Release 2.0.0.4
     * - EventBundleModelProvider nullPointerException수정
     *
     * Date 20210420 : Release 2.0.0.3
     * - exclude logging with manifest metadata
     * - time in front of log_id is set when controller handle the event
     * - deeplink_open after remain in background state for 60 seconds bug fix(on api 29)
     * - is_push_enable default value true
     *
     * Date 20210331 : Release 2.0.0.2
     * - logging with debug app
     * - loginEvent without param, user_id only in userProperties
     * - deeplinkListener
     *
     * Date 20210323 : Release 2.0.0.1
     * - timer.cancel NullPointerException Handling
     *
     * Date 20210311 : Release 2.0.0.0
     * - Adbrix Remaster SDK v2 Release
     *
     */
 }
